import{d as s,a6 as m,z as n,W as e,c as l,g as c,f as u,b as f}from"./index-5eb5c9ac.js";import{I as h}from"./ItemsListing-4e050c6c.js";import"./VCheckbox-2a28a1cd.js";import"./eventbus-4894d390.js";import"./VListItem-b9a4cfb8.js";import"./VCheckboxBtn-cb68b622.js";import"./VList-13fa461d.js";import"./VCardText-1810bf8a.js";import"./VCard-cb863c33.js";import"./VMenu-4088b2e7.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-7b05ebf9.js";import"./Button-64160646.js";import"./VSpacer-81b0afbb.js";/* empty css              */import"./PanelviewItemCompact-4dc20236.js";import"./VAlert-12c553a2.js";import"./Container-1fa5169e.js";import"./Toolbar-6cac4d7d.js";import"./VToolbar-77830c55.js";import"./VTextField-574f2a77.js";import"./VInfiniteScroll-61b7ed02.js";import"./layout-2c007cef.js";import"./VVirtualScroll-5ee5768d.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:r}=m(),a=n(()=>!t.path||t.path=="root"?r("browse"):e("bp6")?r("browse")+" | "+t.path:e("bp3")?t.path:r("browse")),p=async function(o){return await f.browse(o.offset,o.limit,t.path)};return(o,d)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-paged-data":p,"sort-keys":["original","name","name_desc"],title:a.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline","no-server-side-sorting":!0},null,8,["title","path"])]))}});export{J as default};
